import sys
import logging
import inspect
from src.services.orcProcess import orcProcess

class orcLogger():
    def __init__(self, name=""):
        self.name = name

class httpClient():
    def __init__(self, baseUrl):
        self.baseUrl = baseUrl

class orcHttpClient(httpClient):
    def __init__(self):
        baseUrl = 'Orchestra URL'
        super().__init__(baseUrl)

    def kickoff_process(self, correlation_id):
        pass
        # Need to make an API call to orchestra to kick off a process


class systemInfo():
    def __init__(self):
        self.logger = logging.getLogger("orchestra.system_errors")

    def _check_python_deprecations(self):
        # type: () -> None
        version = sys.version_info[:2]

        if version == (3, 4) or version == (3, 5):
            self.logger.warning(
                "orchestra-sdk 0.0.1 will drop support for Python %s.",
                "{}.{}\nPlease upgrade to the latest version to continue receiving upgrades and bugfixes".format(*version),
            )




def run_example_process(correlation_id):
    #Instantiating the orcProcess kicks off an individual process
    orcProcessInstance = orcProcess(correlation_id)

    print('Starting complicated process')

    try:
        print('Trying something complicated')
    except Exception as e:
        print('Failed to do something complicated')
        orcProcessInstance.sendFailure(message = str(e))
    finally:
        print('Completed')
        orcProcessInstance.sendCompletion(message = 'Completed')



from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '0.0.8'
DESCRIPTION = 'Logging module to enable orchestration on self-hosted applications'
LONG_DESCRIPTION = 'A logging-like module to be implemented on self-hosted applications that allows Orchestra to coordinate tasks and gather metadata'

# Setting up
setup(
    name="orchestra-logger",
    version=VERSION,
    author="Orchestra (Hugo Lu)",
    author_email="<hugo@getorchestra.io>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'logging', 'data', 'orchestration'],
    classifiers=[
        'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',      # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9']
)
